# Generated by Django 2.2.13 on 2021-10-04 13:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0019_location_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='location',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
    ]
