# Generated by Django 2.2.13 on 2021-03-19 08:49

from django.db import migrations, models
import measurements.models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0015_auto_20210319_0846'),
    ]

    operations = [
        migrations.AddField(
            model_name='parametermapping',
            name='source_parameter_uom',
            field=models.CharField(blank=True, help_text='unit of measure based on python-pint unit registry (eg. meter, kelvin)', max_length=25, null=True, validators=[measurements.models.validate_uom]),
        ),
    ]
