# Generated by Django 2.2.3 on 2021-01-14 08:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0007_auto_20210113_1138'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='measure',
            unique_together={('serie', 'timestamp')},
        ),
    ]
