# Generated by Django 2.2.13 on 2021-04-27 10:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0017_station_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='station',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to=''),
        ),
    ]
