# Generated by Django 2.2.13 on 2021-08-02 14:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0018_station_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='location',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to=''),
        ),
    ]
