# Generated by Django 2.2.3 on 2021-03-18 11:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0011_auto_20210318_1012'),
    ]

    operations = [
        migrations.CreateModel(
            name='ParameterMapping',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('source_parameter_label', models.CharField(max_length=64)),
                ('data_source', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='measurements.Station')),
                ('parameter', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='measurements.Parameter')),
            ],
        ),
        migrations.AddField(
            model_name='station',
            name='parameters_mapping',
            field=models.ManyToManyField(through='measurements.ParameterMapping', to='measurements.Parameter'),
        ),
    ]
