# Generated by Django 2.2.3 on 2021-02-11 11:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0008_auto_20210114_0832'),
    ]

    operations = [
        migrations.AddField(
            model_name='location',
            name='elevation',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
