# Generated by Django 2.2.3 on 2021-01-13 11:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0006_station_status'),
    ]

    operations = [
        migrations.AlterField(
            model_name='measure',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False),
        ),
    ]
